<?php
/**
* Plugin Name: Listings for Appfolio
* Description: This plugin gets your Appfolio property listings and display them in an interactive way rather than using iframe and gives you styling freedom.
* Version: 1.1.3
* Author: Listings for Appfolio
* Author URI: http://listingsforappfolio.com/
* License: GPL+2
* Text Domain: listings-for-appfolio
* Domain Path: /languages
*/

// Exit if accessed directly
if ( ! defined('ABSPATH') ) {
   exit;
}

add_action( 'init', 'apfl_init_plugin', 1 );
if (!function_exists('apfl_init_plugin')) {
	function apfl_init_plugin(){
		global $apfl_plugin_url;
		global $client_listings_url;
		global $client_gmap_api;
		$apfl_plugin_url = plugin_dir_url( __FILE__ );
		$client_listings_url = get_option('apfl_url');
		$client_gmap_api = get_option('apfl_gmap_api');
		
		add_action( 'wp_enqueue_scripts', 'apfl_styles_scripts' );
		
		// Including main functions
		if(!class_exists ('simple_html_dom')){
			require(plugin_dir_path(__FILE__ ) . 'inc/simple_html_dom.php');
		}
		include(plugin_dir_path(__FILE__ ) . 'inc/single-listing.php');
		include(plugin_dir_path(__FILE__ ) . 'inc/listings.php');
		
		// Shortcodes
		add_shortcode('apfl_listings', 'apfl_display_all_listings');
	}
}

if (!function_exists('apfl_styles_scripts')) {
	function apfl_styles_scripts(){
		wp_enqueue_style(
			'apfl-style',
			plugin_dir_url( __FILE__ ) . 'css/style.css'
		);
	}
}

// Plugin Configuration Page
if(is_admin()){
	add_action('admin_menu', 'apfl_admin_config');
	if (!function_exists('apfl_admin_config')) {
		function apfl_admin_config() {
			add_options_page('Listings for Appfolio', 'Listings for Appfolio', 'manage_options', 'apfl', 'apfl_config_callback'); 
		}
	}
	if (!function_exists('apfl_config_callback')) {
		function apfl_config_callback(){
			if (!current_user_can('manage_options')){
				wp_die( __('You do not have sufficient permissions to access this page.') );
			}
			
			if($_POST){
				if(isset($_POST['apfl_config_submit'])){
					if(isset($_POST['apfl_config_url'])){
						$apfl_url = sanitize_text_field($_POST['apfl_config_url']);
						$apfl_url_updated = update_option('apfl_url', $apfl_url);
					}
					if(isset($_POST['apfl_config_gmap_api'])){
						$apfl_gmap_api = sanitize_text_field($_POST['apfl_config_gmap_api']);
						$apfl_gmap_api_updated = update_option('apfl_gmap_api', $apfl_gmap_api);
					}
					
					// Saved message
					if($apfl_url_updated || $apfl_gmap_api_updated){
						echo '<div class="notice notice-success is-dismissible"><p>Settings Saved!</p></div>';
					}
				}
			}
			?>

			<div class="wrap">
				<div id="apfl_settings">
					<form method='POST' action="">
						<br>
						<p style=" margin: 0; padding: 12px 15px; background: rgb(89, 143, 205); font-size: 16px; color: #fff; display: inline-block; margin-bottom: 10px;">If you like this plugin, please <a href="https://wordpress.org/support/plugin/listings-for-appfolio/reviews/#new-post" style="font-weight: bold; color: #fff;" target="_blank">Add Your Review.</a> Looking for more features and customization options? See the PRO version <a target="_blank" href="https://listingsforappfolio.com/" style="font-weight: bold; color: #fff;">here</a></p>
						<h1>Listings for Appfolio Settings <span style="font-size: 15px;background: lightgrey;padding: 4px 10px;">shortcode - [apfl_listings]</span></h1>
						<table class="form-table">
							<tr>
								<th>
									<?php $apfl_listing_url = get_option('apfl_url'); ?>
									<label for="apfl_config_url">Appfolio URL to fetch listings: </label>
								</th>
								<td>
									<input type="text" name="apfl_config_url" id="apfl_config_url" style="min-width: 350px;" placeholder="For Example - https://example.appfolio.com" value="<?php echo $apfl_listing_url; ?>">
								</td>
							</tr>
							
							<tr>
								<th>
									<?php $apfl_gmap_api = get_option('apfl_gmap_api'); ?>
									<label for="apfl_config_gmap_api">Google Map JS API Key</label>
								</th>
								<td>
									<input type="text" name="apfl_config_gmap_api" id="apfl_config_gmap_api" style="min-width: 350px;" placeholder="Leave Blank to disable Google Map" value="<?php echo $apfl_gmap_api; ?>">
								</td>
							</tr>
						</table>
						
						<p class="submit">
							<input type="submit" name="apfl_config_submit" id="apfl_config_submit" class="button-primary" value="Save"/>
						</p>
					</form>
				</div>
			</div>
		<?php
		}
	}
}
